#include "stm32f10x.h"
#include "images.h"

int currentImage = 0;

void SystemInit(void)
{
	// Enable Prefetch Buffer
	FLASH->ACR |= FLASH_ACR_PRFTBE;
    // Flash 2 wait state 
    FLASH->ACR = (FLASH->ACR & ~FLASH_ACR_LATENCY) | FLASH_ACR_LATENCY_2; 

	// Enable HSE 
	RCC->CR |= RCC_CR_HSEON;
	while (RCC->CR & RCC_CR_HSERDY == 0);
							
  	// PREDIV1 source = HSE
	RCC->CFGR &= ~RCC_CFGR_PPRE1;

	// PLLSRC = PREDIV1
	RCC->CFGR |= RCC_CFGR_PLLSRC;
							  
	// PLL = PREDIV1 * 9 => SYSCLK = 72 MHz
	RCC->CFGR = (RCC->CFGR & ~RCC_CFGR_PLLMULL) | RCC_CFGR_PLLMULL_2 | RCC_CFGR_PLLMULL_1 | RCC_CFGR_PLLMULL_0;
							  
	// PLL enable
	RCC->CR |= RCC_CR_PLLON;
	while ((RCC->CR & RCC_CR_PLLRDY) == 0);

    RCC->CFGR = (RCC->CFGR & ~RCC_CFGR_SW) | RCC_CFGR_SW_PLL;
	while((RCC->CFGR & RCC_CFGR_SWS) != RCC_CFGR_SWS_PLL);
}

void EXTI3_IRQHandler()
{
/*	int i, j;
	for (j=0; j<0xf; j++)
		for (i=0; i<0x3fff; i++);
  */  
	if ((GPIOA->IDR & (1 << 3)) != 0)
	{
		if (++currentImage == 2) currentImage = 0;
		switch (currentImage)
		{
		case 0:
			ISC15ANP4_Transition(cortex, isc15anp4);
			break;
		case 1:
		    ISC15ANP4_Transition(isc15anp4, cortex);
		}
	}
	EXTI->PR |= EXTI_PR_PR3;
}

void ConfigEXTI()
{
	GPIOA->CRL &= ~(GPIO_CRL_MODE3 | GPIO_CRL_CNF3);
	GPIOA->CRL |= GPIO_CRL_CNF3_1;
	GPIOA->ODR &= ~(1 << 3);

    AFIO->EXTICR[0] |= AFIO_EXTICR1_EXTI3_PA; 
	
		
	EXTI->IMR |= EXTI_IMR_MR3;
	EXTI->RTSR |= EXTI_RTSR_TR3;

	NVIC->ISER[0] |= NVIC_ISER_SETENA_9;	
}


int main()
{
	ISC15ANP4_Init();	
	ISC15ANP4_SetRangeToFullScreen();
	ISC15ANP4_DrawScreen(isc15anp4);
	ConfigEXTI();
	while(1);																 
}
